@@ -215,7 +215,7 @@ Common causes for failures:
 @click.pass_context
 def instance_ssh(ctx, public):
     session = ctx.obj.session
-    svc = ctx.obs.service
+    svc = ctx.obj.service
     job_resource = ctx.obj.job
     job_id = job_resource['job_id']
     worker = get_instance_for_job(session, job_resource)
