@@ -39,7 +39,7 @@ def cli(ctx):
         ctx.obj.service = ctx.obj.client.service("query")
 
 
-from nextcodecli.commands.query.run import run, project, info, results, cancel, list_queries
+from nextcodecli.commands.query.run import run, project, info, results, cancel, list_queries, progress
 from nextcodecli.commands.query.templates import templates
 from nextcodecli.commands.query.status import status
 
@@ -48,6 +48,7 @@ cli.add_command(project)
 cli.add_command(info)
 cli.add_command(results)
 cli.add_command(cancel)
+cli.add_command(progress)
 cli.add_command(list_queries)
 
 cli.add_command(templates)
