@@ -137,6 +137,7 @@ def info(ctx, query_id, is_raw):
     print_tab("ID", data['id'])
     print_tab("Submitted", data['submit_date'])
     print_tab("User", data['user_name'])
+    print_tab("Available", data['available'])
     status = data['status']
     col = 'red'
     if status == 'DONE':
@@ -214,6 +215,34 @@ def cancel(ctx, query_id):
     click.secho("Query has been cancelled.", fg='yellow', bold=True)
 
 
+@click.command()
+@click.argument('query_id', nargs=1)
+@click.option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
+@click.pass_context
+@check_project
+def progress(ctx, query_id, is_raw):
+    """
+    View the progress of a running query
+    """
+    svc = ctx.obj.service
+
+    qry = svc.get_query(query_id)
+    if qry.status != "RUNNING":
+        abort("Query is not RUNNING")
+
+    if is_raw:
+        click.echo(dumps(qry.progress))
+        return
+
+    fields = ["job_id", "status", "fingerprint", "bytes", "lines"]
+
+    rows = []
+    for job_id, job in qry.progress.items():
+        rows.append([job_id, job['job-status'], job.get('fingerprint'), job.get('queryByteCount'), job.get('queryLineCount')])
+    tbl = tabulate(rows, headers=fields)
+    click.echo(tbl)
+
+
 @click.command("list")
 @click.option('-u', '--user', 'user_name', help='User to filter for')
 @click.option('-s', '--status', 'status', default=None, help='Filter status')
