@@ -97,7 +97,11 @@ def inspect(ctx, is_raw):
         if status in ('PENDING', 'STARTED'):
             secho("Nextflow executor pod not Found. This job is not running!", fg='red')
     else:
-        pod_state = executor_pod['status']['container_statuses'][0]['state']
+        status = executor_pod['status']
+        container_statuses = status['container_statuses']
+        pod_state = {}
+        if container_statuses:
+            pod_state = container_statuses[0]['state']
         node_name = executor_pod['spec']['node_name']
         print_tab('Executor node name', node_name)
         secho("\nExecutor Pod State:", bold=True)
@@ -193,6 +197,7 @@ def view(ctx, is_raw):
     if not pipeline_name:
         pipeline_name = "(custom)"
     print_tab('pipeline_name', pipeline_name)
+    print_tab('description', workflow_job.description)
     submit_date = workflow_job.submit_date
     print_tab('submitted', submit_date.strftime('%Y-%m-%d %H:%M:%S'))
     complete_date = workflow_job.complete_date or datetime.datetime.utcnow()
@@ -662,7 +667,7 @@ def link(ctx, link_type):
         echo(link)
         click.launch(link)
     elif link_type == 'grafana':
-        parts = urlsplit(ctx.obs.service.base_url)
+        parts = urlsplit(ctx.obj.service.base_url)
         grafana_url = urljoin('%s://%s' % (parts.scheme, parts.netloc), 'admin/grafana')
 
         from_timestamp = int(time.mktime(start_date.timetuple()) * 1000)
